==> config_export_import-8.x-1.3.tar.gz: config_export_import/src/Form/ConfigImportBatchForm.php <==
<?php

namespace Drupal\config_export_import\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Config\FileStorage;
/**
 * Class ConfigImportForm.
 */
class ConfigImportBatchForm extends FormBase {


//  /**
//   * {@inheritdoc}
//   */
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'config_import_batch_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
            $helper = \Drupal::service('config_export_import.manager');
            $query = $this->getRequest()->query->all();
            $current_config = [];
            $dependencies_current = [];
            $config_settings = \Drupal::config("config_export_import.settings") ;
            $root =  $config_settings->get('root');
            $form['help'] = [
                '#type' => 'item',
                '#markup' => '<h2>Drag to re-order the config elements according the dependency level <h2>'
            ];
            if (isset($query['import_file'])
                && isset($query['import_file']['path'])
                && isset($query['import_file']['type'])
                && $query['import_file']['type'] == 'file'
            ) {
                $config_path = DRUPAL_ROOT.$root;
                $file = $config_path.$query['import_file']['file'] ;
                $dependencies_current = $helper->getAllDependencyByFolder($file);
                if(!is_array($dependencies_current) && $dependencies_current == false){
                  $error = false ;
                }
                $config_name = basename($file,'.yml') ;
                $file = $helper->removeFullPath($file);
                $status = $helper->renderStatus($config_name);
                $current_config[$config_name] = [
                    "config_name" => $status,
                    "file" => $file,
                    'weight' => 1
                ];
            }
            // *** Import Request *** //
            if (isset($query['import_dir'])
                && isset($query['import_dir']['path'])
                && isset($query['import_dir']['type'])
                && $query['import_dir']['type'] == 'dir'
            ) {

                $path = $query['import_dir']['path'] ;
                $config_path = DRUPAL_ROOT.$root.$path;
                $results = $helper->readDirectoryFile($config_path,'yml');
                if(!empty($results)){
                    foreach ($results as $key => $file){
                        $childs = $helper->getAllDependencyByFolder($file);
                        if(is_array($childs)){
                            $dependencies_current = array_merge($childs , $dependencies_current);
                        }else{
                            $error = true ;
                        }
                    }
                    foreach ($results as $key => $file) {
                        $config_name = basename($file,'.yml') ;
                        $config_dep = array_keys($dependencies_current);
                        if(!in_array($config_name,$config_dep)){
                            $file = $helper->removeFullPath($file);
                            $status = $helper->renderStatus($config_name);
                            $current_config[$config_name] = [
                                "config_name" => $status,
                                "file" => $file,
                                'weight' => 1
                            ];
                        }
                    }

                }

            }
      
            //  ***** FORM **** //
        //    $form_state->setMethod('GET');
            $form['display_config'] = [
                '#type' => 'details',
                '#open' => FALSE,
                '#title' => $this->t('LIST OF CONFIG FILE')
            ];
            $group_class = 'group-order-weight';
            $form['display_config']['table'] = array(
                '#type' => 'table',
                '#header' => [  
                    'config_render' => t('Config'),
                    'enable' => t('Enabled'),
                    'file path' => t('Path location'),
                    'weight' => t('Weight')
                ],
                '#tableselect' => FALSE,
                '#tabledrag' => [
                  [
                    'action' => 'order',
                    'relationship' => 'sibling',
                    'group' => $group_class,
                  ]
                  ],
                '#empty' => $this->t('No items found')
            );
            $form['display'] = [
                '#type' => 'details',
                '#open' => FALSE,
                '#title' => $this->t('LIST OF DEPENDANCES')
            ];
           
            $form['display']['table_dep'] = array(
                '#type' => 'table',
                '#header' => [  
                    'config_render' => t('Dependencies'),
                    'enable' => t('Enabled'),
                    'file path' => t('Path location'),
                    'weight' => t('Weight')
                ],
                '#tableselect' => FALSE,
                '#tabledrag' => [
                  [
                    'action' => 'order',
                    'relationship' => 'sibling',
                    'group' => $group_class,
                  ]
                  ],
                '#empty' => $this->t('No items found')
            );
            foreach ($current_config as $key => $config){
                $form['display_config']['table'][$key]['#attributes']['class'][] = 'draggable';
                $form['display_config']['table'][$key]['#weight'] = $config['#weight'];
                  // Label col.
                  $form['display_config']['table'][$key]['config_render'] = [
                    '#markup' =>  $config['config_name'],
                ];
                $form['display_config']['table'][$key]['check']= array(
                    '#type' => 'checkbox',
                    '#default_value' => 1
                );
                // ID col.
                $form['display_config']['table'][$key]['file'] = [
                    '#plain_text' => $config['file'],
                ];
      
                $form['display_config']['table'][$key]['weight'] = [
                    '#type' => 'weight',
                    '#title' => $this->t('Weight'),
                    '#title_display' => 'invisible',
                    '#default_value' => $config['weight'],
                    '#attributes' => ['class' => [$group_class]],
                  ];
            }
            foreach ($dependencies_current as $key => $dep){
                $form['display']['table_dep'][$key]['#attributes']['class'][] = 'draggable';
                $form['display']['table_dep'][$key]['#weight'] = $dep['#weight'];
                  // Label col.
                  $form['display']['table_dep'][$key]['config_render'] = [
                    '#markup' =>  $dep['config_name'],
                ];
                $form['display']['table_dep'][$key]['check']= array(
                    '#type' => 'checkbox',
                    '#default_value' => 1,
                    '#attributes' => array('checked' => 'checked')
                );
                // ID col.
                $form['display']['table_dep'][$key]['file'] = [
                    '#plain_text' => $dep['file'],
                ];
                $form['display']['table_dep'][$key]['weight'] = [
                    '#type' => 'weight',
                    '#title' => $this->t('Weight '),
                    '#title_display' => 'invisible',
                    '#default_value' =>$dep['#weight'],
                    '#attributes' => ['class' => [$group_class]],
                  ];
            }

            $form['dependencies'] = [
                '#type' => 'checkbox',
                '#default_value' => 1,
                '#title' => t('Import only if config dependencies is new in database'),
                '#attributes' => array('checked' => 'checked')
            ];
            $form['actions'] = ['#type' => 'actions'];
            $form['actions']['submit'] = [
                '#type' => 'submit',
                '#value' => 'Process import config',
            ];
            $form['actions']['cancel'] = array(
                '#type' => 'link',
                '#title' => $this->t('BACK TO IMPORT LIST'),
                '#url' => $this->buildCancelLinkUrl(),
            );
            $form['dep'] = [
                '#type' => 'item',
                '#value' => $dependencies_current
            ];
            $form['config'] = [
                '#type' => 'item',
                '#value' => $current_config
            ];
           $form_state->setCached(FALSE);
           $form['#cache'] = ['max-age' => 0];
        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {

    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $helper = \Drupal::service('config_export_import.manager');
        $values = $form_state->getValues();
        $batch = [
            'title' => $this->t('Import Config From yml...'),
            'operations' => [],
            'init_message' => $this->t('Starting ..'),
            'progress_message' => $this->t('Processd @current out of @total.'),
            'error_message' => $this->t('An error occurred during processing.'),
            'finished' => 'Drupal\config_export_import\ConfigExportImportManager::importFinishedCallback',
        ];
        $config_settings = \Drupal::config("config_export_import.settings");
        $root = $config_settings->get('root');
        $config_path = DRUPAL_ROOT . $root;
        if(!empty($values['dep'])){
            foreach ($values['table_dep'] as $key => $item){
                if(isset($item['check']) && $item['check']==1 ){
                    $file = $values['dep'][$key] ;
                    if($file['file'] != '--'){
                        $file = $file['file'] ;
                        $config_name = basename($file,'.yml');
                        $file = $config_path .$file ;
                        if($values['dependencies'] && $values['dependencies'] == 1){
                            if(!$helper->isExistDatabase( $config_name )){
                            $batch['operations'][] = [$helper->importConfig($file), []];
                            }
                        }else{
                            $batch['operations'][] = [$helper->importConfig($file), []];
                        }
                    }
                }
            }
        }
        if(!empty($values['config'])){
            foreach ($values['table'] as $key => $item){
                if(isset($item['check']) && $item['check']==1 ){
                    $file = $values['config'][$key] ;
                    $file = $file['file'] ;
                    $file = $config_path .$file ;
                    $batch['operations'][] = [$helper->importConfig($file), []];

                }
            }
        }

        batch_set($batch);

    }

    protected function getEditableConfigNames()
    {
        return [
            'config_export_import.config_import_batch',
        ];
    }
    /**
     * Builds the cancel link url for the form.
     *
     * @return Url
     *   Cancel url
     */
    private function buildCancelLinkUrl()
    {
        return Url::fromRoute('config_export_import.manual_import');
    }

}

==> config_export_import-8.x-1.5.tar.gz: config_export_import/src/Form/ConfigImportBatchForm.php <==
<?php

namespace Drupal\config_export_import\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Config\FileStorage;
/**
 * Class ConfigImportForm.
 */
class ConfigImportBatchForm extends FormBase {


//  /**
//   * {@inheritdoc}
//   */
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'config_import_batch_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
            $helper = \Drupal::service('config_export_import.manager');
            $query = $this->getRequest()->query->all();
            $current_config = [];
            $dependencies_current = [];
            $config_settings = \Drupal::config("config_export_import.settings") ;
            $root =  $config_settings->get('root');
            $form['help'] = [
                '#type' => 'item',
                '#markup' => '<h2>Drag to re-order the config elements according the dependency level <h2>'
            ];
            if (isset($query['import_file'])
                && isset($query['import_file']['path'])
                && isset($query['import_file']['type'])
                && $query['import_file']['type'] == 'file'
            ) {
                $config_path = DRUPAL_ROOT.$root;
                $file = $config_path.$query['import_file']['file'] ;
                $dependencies_current = $helper->getAllDependencyByFolder($file);
                if(!is_array($dependencies_current) && $dependencies_current == false){
                  $error = false ;
                }
                $config_name = basename($file,'.yml') ;
                $file = $helper->removeFullPath($file);
                $status = $helper->renderStatus($config_name);
                $current_config[$config_name] = [
                    "config_name" => $status,
                    "file" => $file,
                    'weight' => 1
                ];
            }
            // *** Import Request *** //
            if (isset($query['import_dir'])
                && isset($query['import_dir']['path'])
                && isset($query['import_dir']['type'])
                && $query['import_dir']['type'] == 'dir'
            ) {

                $path = $query['import_dir']['path'] ;
                $config_path = DRUPAL_ROOT.$root.$path;
                $results = $helper->readDirectoryFile($config_path,'yml');
                if(!empty($results)){
                    foreach ($results as $key => $file){
                        $childs = $helper->getAllDependencyByFolder($file);
                        if(is_array($childs)){
                            $dependencies_current = array_merge($childs , $dependencies_current);
                        }else{
                            $error = true ;
                        }
                    }
                    foreach ($results as $key => $file) {
                        $config_name = basename($file,'.yml') ;
                        $config_dep = array_keys($dependencies_current);
                        if(!in_array($config_name,$config_dep)){
                            $file = $helper->removeFullPath($file);
                            $status = $helper->renderStatus($config_name);
                            $current_config[$config_name] = [
                                "config_name" => $status,
                                "file" => $file,
                                'weight' => 1
                            ];
                        }
                    }

                }

            }
      
            //  ***** FORM **** //
        //    $form_state->setMethod('GET');
            $form['display_config'] = [
                '#type' => 'details',
                '#open' => FALSE,
                '#title' => $this->t('LIST OF CONFIG FILE')
            ];
            $group_class = 'group-order-weight';
            $form['display_config']['table'] = array(
                '#type' => 'table',
                '#header' => [  
                    'config_render' => t('Config'),
                    'enable' => t('Enabled'),
                    'file path' => t('Path location'),
                    'weight' => t('Weight')
                ],
                '#tableselect' => FALSE,
                '#tabledrag' => [
                  [
                    'action' => 'order',
                    'relationship' => 'sibling',
                    'group' => $group_class,
                  ]
                  ],
                '#empty' => $this->t('No items found')
            );
            $form['display'] = [
                '#type' => 'details',
                '#open' => FALSE,
                '#title' => $this->t('LIST OF DEPENDANCES')
            ];
           
            $form['display']['table_dep'] = array(
                '#type' => 'table',
                '#header' => [  
                    'config_render' => t('Dependencies'),
                    'enable' => t('Enabled'),
                    'file path' => t('Path location'),
                    'weight' => t('Weight')
                ],
                '#tableselect' => FALSE,
                '#tabledrag' => [
                  [
                    'action' => 'order',
                    'relationship' => 'sibling',
                    'group' => $group_class,
                  ]
                  ],
                '#empty' => $this->t('No items found')
            );
            foreach ($current_config as $key => $config){
                $form['display_config']['table'][$key]['#attributes']['class'][] = 'draggable';
               // $form['display_config']['table'][$key]['#weight'] = $config['weight'];
                  // Label col.
                  $form['display_config']['table'][$key]['config_render'] = [
                    '#markup' =>  $config['config_name'],
                ];
                $form['display_config']['table'][$key]['check']= array(
                    '#type' => 'checkbox',
                    '#default_value' => 1
                );
                // ID col.
                $form['display_config']['table'][$key]['file'] = [
                    '#plain_text' => $config['file'],
                ];
      
                $form['display_config']['table'][$key]['weight'] = [
                    '#type' => 'weight',
                    '#title' => $this->t('Weight'),
                    '#title_display' => 'invisible',
                    '#attributes' => ['class' => [$group_class]],
                  ];
            }
            foreach ($dependencies_current as $key => $dep){
                $form['display']['table_dep'][$key]['#attributes']['class'][] = 'draggable';
              //  $form['display']['table_dep'][$key]['#weight'] = $dep['#weight'];
                  // Label col.
                  $form['display']['table_dep'][$key]['config_render'] = [
                    '#markup' =>  $dep['config_name'],
                ];
                $form['display']['table_dep'][$key]['check']= array(
                    '#type' => 'checkbox',
                    '#default_value' => 1,
                    '#attributes' => array('checked' => 'checked')
                );
                // ID col.
                $form['display']['table_dep'][$key]['file'] = [
                    '#plain_text' => $dep['file'],
                ];
                $form['display']['table_dep'][$key]['weight'] = [
                    '#type' => 'weight',
                    '#title' => $this->t('Weight '),
                    '#title_display' => 'invisible',
                  //  '#default_value' =>$dep['#weight'],
                    '#attributes' => ['class' => [$group_class]],
                  ];
            }

            $form['dependencies'] = [
                '#type' => 'checkbox',
                '#default_value' => 1,
                '#title' => t('Import only if config dependencies is new in database'),
                '#attributes' => array('checked' => 'checked')
            ];
            $form['actions'] = ['#type' => 'actions'];
            $form['actions']['submit'] = [
                '#type' => 'submit',
                '#value' => 'Process import config',
            ];
            $form['actions']['cancel'] = array(
                '#type' => 'link',
                '#title' => $this->t('BACK TO IMPORT LIST'),
                '#url' => $this->buildCancelLinkUrl(),
            );
            $form['dep'] = [
                '#type' => 'item',
                '#value' => $dependencies_current
            ];
            $form['config'] = [
                '#type' => 'item',
                '#value' => $current_config
            ];
           $form_state->setCached(FALSE);
           $form['#cache'] = ['max-age' => 0];
        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {

    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $helper = \Drupal::service('config_export_import.manager');
        $values = $form_state->getValues();
        $batch = [
            'title' => $this->t('Import Config From yml...'),
            'operations' => [],
            'init_message' => $this->t('Starting ..'),
            'progress_message' => $this->t('Processd @current out of @total.'),
            'error_message' => $this->t('An error occurred during processing.'),
            'finished' => 'Drupal\config_export_import\ConfigExportImportManager::importFinishedCallback',
        ];
        $config_settings = \Drupal::config("config_export_import.settings");
        $root = $config_settings->get('root');
        $config_path = DRUPAL_ROOT . $root;
        if(!empty($values['dep'])){
            foreach ($values['table_dep'] as $key => $item){
                if(isset($item['check']) && $item['check']==1 ){
                    $file = $values['dep'][$key] ;
                    if($file['file'] != '--'){
                        $file = $file['file'] ;
                        $config_name = basename($file,'.yml');
                        $file = $config_path .$file ;
                        if($values['dependencies'] && $values['dependencies'] == 1){
                            if(!$helper->isExistDatabase( $config_name )){
                            $batch['operations'][] = [$helper->importConfig($file), []];
                            }
                        }else{
                            $batch['operations'][] = [$helper->importConfig($file), []];
                        }
                    }
                }
            }
        }
        if(!empty($values['config'])){
            foreach ($values['table'] as $key => $item){
                if(isset($item['check']) && $item['check']==1 ){
                    $file = $values['config'][$key] ;
                    $file = $file['file'] ;
                    $file = $config_path .$file ;
                    $batch['operations'][] = [$helper->importConfig($file), []];

                }
            }
        }

        batch_set($batch);

    }

    protected function getEditableConfigNames()
    {
        return [
            'config_export_import.config_import_batch',
        ];
    }
    /**
     * Builds the cancel link url for the form.
     *
     * @return Url
     *   Cancel url
     */
    private function buildCancelLinkUrl()
    {
        return Url::fromRoute('config_export_import.manual_import');
    }

}
